"""
Utility functions and classes.

You have to import sub-modules of `healpy.utils` directly,
the `healpy.utils` namespace is empty.

Examples::
    from healpy.utils.deprecation import HealpyDeprecationWarning
"""
